import { Toast } from "vant";

export function paramsToQuery(params) {
  const parts = Object.keys(params || {}).map(key => `${encodeURIComponent(key)}=${encodeURIComponent(params[key])}`)
  return parts.length > 0 ? parts.join('&') : ''
}

export default function request (url, options = {}) {
  const headers = new Headers();
  headers.append('Content-Type', 'application/json;charset=utf8');
  // headers.append('credentials', 'include');
  // headers.append('mode', 'cors');

  const { params, loading, ...leftOptions } = options
  const fetchURL = params ? `${url}?${paramsToQuery(params)}` : url

  Object.keys(options.headers || {}).forEach(key => headers.append(key, options.headers[key]))

  let toast = null;
  if (loading) {
    toast = Toast.loading({
      message: '请稍候...',
      forbidClick: true,
      duration: 0
    });
  }

  return fetch(fetchURL, { ...leftOptions, headers, credentials: 'same-origin' })
    .then(response => response.json())
    .then(data => {
      if (toast) toast.clear();
      if (data.code === 1000) return data.data
      return Promise.reject(data)
    }).catch(err => {
      if (toast) toast.clear();
      return Promise.reject(err)
    })
}

export const baseURL = `${import.meta.env.VITE_SERVER_BASE}/api/h5`
